import os

class making_directory:
    """
    Pass the parameters
    """
    def __init__(self, location, chunks_list_first,dictionary):
        self.location = location
        self.chunks_list_first = chunks_list_first
        self.dictionary = dictionary

    def making_directory(location, chunks_list_first,dictionary):
        for items in chunks_list_first:
            path = os.path.join(location,items)
            os.mkdir(path)
            for key in dictionary:
                if items == key:
                    for values in dictionary[key]:
                        os.makedirs(os.path.join(path,values))


import csv

class generate_report_2:
    """
    Initiate generating report 2 which contains about information on those report, please pass the params include location and report_distinct"""
    def __init__(self, location, report_distinct):
        self.location = location
        self.report_distinct = report_distinct
        
    def create_report_log_petak(location,report_distinct):
        with open(location + "\\" + "Log Petak.csv","w",newline="") as f:
            csv2 = csv.writer(f, delimiter=",")
            csv2.writerow(["Chunk Name","Keyid","UAV Start","UAV End","Plant Date","Umur (Hari)","Plant Species","GSD","Filename","Image Accuracy"])
            for d in report_distinct:
                split_report = d.split("-")
                csv2.writerow([split_report[0],split_report[1],split_report[2],split_report[3],split_report[4],split_report[5],split_report[6],split_report[7],split_report[8],split_report[9]])
    


import csv
import os

class generate_merge_report_camera:
    """
    Pleas pass the params to generate merge log petak"""
    def __init__(self,location,directory):
        self.location = location
        self.directory = directory

    def generate_merge_report_camera(location, directory):
        substring = "Camera Accuracy"
        headers = []
        rows_csv_merge = []

        for file in os.listdir(location + "\\Report Per Chunk"):
            move_folder = os.path.join(location,directory)
            #Create Prioritas Ketiga CSV
            csv_reader = csv.reader(open(os.path.join(move_folder,file)))
            header = next(csv_reader)
            headers.append(header)
            
            for row in csv_reader:
                rows_csv_merge.append(row)
            
        with open(location + "\\" + "test" + "_" + "prioritas_ketiga.csv","w",newline="") as q:
            csv2 = csv.writer(q, delimiter = ",")
            fields = ["Chunk Name","Keyid", "Camera Name", "Longitude", "Latitude", "Altitude", "Long Accuracy", "Lat Accuracy", "Alt Accuracy"]
            csv2.writerow(fields)

            for r in rows_csv_merge:
                csv2.writerow([r[0],r[1],r[2],r[3],r[4],r[5],r[6],r[7],r[8]])


import os
import csv
import shutil

class copy_selected_foto:
    """
    This is testing
    """
    def __init__(self, location, substring, src_raw_foto, chunks_list_first):
        self.location = location
        self.substring = substring
        self.src_raw_foto = src_raw_foto
        self.chunks_list_first = chunks_list_first

    def copy_selected_foto(location, substring, src_raw_foto, chunks_list_first):
        rows_csv_merge = []
        for i in os.listdir(location):
            if i.find(substring) != -1:
                csv_reader = csv.reader(open(os.path.join(location,i)))
                header = next(csv_reader)

                for row in csv_reader:
                    rows_csv_merge.append(row)

        for i in range(len(src_raw_foto)):
            chunk_name_raw = (str(src_raw_foto[i].split("-")[0]))
            src_path_raw = (str(src_raw_foto[i].split("-")[1]))

            for chunk in chunks_list_first:
                    if chunk_name_raw == str(chunk):
                        for file_name in os.listdir(src_path_raw):
                            source = src_path_raw + "/" + file_name
                            for file in rows_csv_merge:
                                destination = location + "/" + file[0] + "/" + file[1] + "/" + file_name
                                if os.path.isfile(source) and (file_name == file[2] + ".jpg" or file_name == file[2] + ".JPG"):
                                    shutil.copy(source,destination)
                                    print("copied",file_name)


import os
import csv
import shutil

class process_foto:
    """
    This is a function to generating 9 photos per each folder, please pass the params to process the function"""
    def __init__(self, location,chunk_shape_dictionary):
        self.location = location
        self.chunk_shape_dictionary = chunk_shape_dictionary

    def process_foto(location, chunk_shape_dictionary):
        path_new = []
        for key in chunk_shape_dictionary:
            path_new_append = str(location) + "/" + str(key) 
            path_new.append(path_new_append)
        
        path_new_2 = []
        for path in path_new:
            foldernames_2 = os.listdir(path)
            for folder in foldernames_2:
                path_new_2.append(str(path) + "/" + str(folder))
        
        arranged_dict = {}
        for path_foto in path_new_2:
            path_foto_arrange = []
            foldernames_3 = os.listdir(path_foto)
            if len(foldernames_3) > 0:
                folder_names_4 = foldernames_3[0:9]
                for file in folder_names_4:
                    path_foto_arrange.append(str(file))
                arranged_dict[path_foto] = path_foto_arrange
        
        path_raw = []
        list_b = []

        for folder, files in arranged_dict.items():
            path_raw.append(folder)
            for file in files:
                list_b.append(str(folder) + "/" + str(file))
        
        list_a = []
        for file in path_raw:
            for photo in os.listdir(file):
                list_a.append(str(file) + "/" + str(photo))
        
        def non_match_elements(list_a, list_b):
            non_match = []
            for i in list_a:
                if i not in list_b:
                    non_match.append(i)
            return non_match

        non_match = non_match_elements(list_a,list_b)

        for deleted in non_match:
            os.remove(deleted)
            print("Deleting File ", non_match)
        for (root,dirs,files) in os.walk(location):
            print(root)



import os
import csv

class generate_log_raw_petak:
    """
    This is a function to generate new report that consist by 9 photos per shape, please pass the params to execute the function
    """
    def __init__(self,location,chunk_shape_dictionary):
        self.location = location
        self.chunk_shape_dictionary = chunk_shape_dictionary

    def generate_log_raw_petak(path_ekspor,chunk_shape_dictionary):
        path_new = []
        for key in chunk_shape_dictionary:
            path_new_append = str(path_ekspor) + "/" + str(key) 
            path_new.append(path_new_append)

        path_new_2 = []
        for path in path_new:
            foldernames_2 = os.listdir(path)
            for folder in foldernames_2:
                path_new_2.append(str(path) + "/" + str(folder))

        arranged_dict = {}
        for path_foto in path_new_2:
            path_foto_arrange = []
            foldernames_3 = os.listdir(path_foto)
            if len(foldernames_3) > 0:
                folder_names_4 = foldernames_3[0:9]
                for file in folder_names_4:
                    path_foto_arrange.append(str(file))
                arranged_dict[path_foto] = path_foto_arrange

        path_raw = []
        list_b = []
        for folder, files in arranged_dict.items():
            path_raw.append(folder)
            for file in files:
                list_b.append(str(folder) + "/" + str(file))

        new_csv = []
        for l in list_b:
            get_csv = l.split("/")
            new_csv.append(get_csv[len(get_csv)-3:len(get_csv)])

        foldernames = os.listdir(path_ekspor)
        substring = "prioritas_ketiga"
        rows_csv_merge = []
        for i in foldernames:
            if i.find(substring) != -1:
                csv_reader = csv.reader(open(os.path.join(path_ekspor,i)))
                header = next(csv_reader)

                for row in csv_reader:
                    rows_csv_merge.append(row)
            
        with open(path_ekspor + "\\" + "Log Raw Petak.csv","w",newline="") as fp:
            a = csv.writer(fp,delimiter=",")
            fields=["Chunk Name","Keyid","Camera Name","Longitude","Latitude","Altitude","Longitude Accuracy", "Latitude Accuracy","Altitude Accuracy"]
            a.writerow(fields)

            for n in new_csv:
                chunk_new = n[0]
                shape_new = n[1]
                photo_new = n[2]
                for r in rows_csv_merge:
                    chunk_old = r[0]
                    shape_old = r[1]
                    photo_old = r[2]
                    long_old = r[3]
                    lat_old = r[4]
                    alt_old = r[5]
                    long_acc = r[6]
                    lat_acc = r[7]
                    alt_acc = r[8]
                    if chunk_new == chunk_old and shape_new == shape_old and (photo_new == (photo_old + ".jpg") or photo_new == (photo_old + ".JPG")):
                        a.writerow([chunk_old,shape_old,photo_old,long_old,lat_old,alt_old,long_acc,lat_acc,alt_acc])
    


import csv

class create_csv:
    """
    Initiate create CSV project.
    Please Pass the required params"""
    def __init__(self, location,chunk_name, camera_list,chunk_name_list, keyid_list,rows,chunk_name_real_2):
        self.location = location
        self.chunk_name = chunk_name
        self.camera_list = camera_list
        self.chunk_name_list = chunk_name_list
        self.keyid_list = keyid_list
        self.rows = rows
        self.chunk_name_real_2 = chunk_name_real_2
        
    def create_csv(location,chunk_name, camera_list,chunk_name_list, keyid_list,rows,chunk_name_real_2):
        with open(location + "\\" + chunk_name + "_Camera Accuracy.csv","w",newline="") as fp:
            a = csv.writer(fp, delimiter=",")
            fields = ["Chunk Name", "Keyid","Camera Name","Longitude","Latitude","Altitude","Longitude Accuracy", "Latitude Accuracy","Altitude Accuracy"]
            a.writerow(fields)
            for i in range(len(camera_list)):
                chunk_selected = chunk_name_list[i]
                camera_selected = camera_list[i]
                keyid_csv = keyid_list[i]
                for r in rows:
                    camera_raw = r[0]
                    latitude_raw = r[2]
                    longitude_raw = r[3]
                    altitude_raw = r[4]
                    latitude_acc_raw = r[5]
                    longitude_acc_raw = r[6]
                    altitude_acc_raw = r[7]
                    chunk_raw = r[8]
                    if chunk_selected == chunk_raw and camera_selected == camera_raw:
                        a.writerow([chunk_name_real_2,keyid_csv,camera_raw,longitude_raw,latitude_raw,altitude_raw,longitude_acc_raw,latitude_acc_raw,altitude_acc_raw])


import copy
import os, shutil

class copy_camera_accuracy:
    """
    This Function will copy your CSV which contain Camera Accuracy Name, and will move those file to Report Per Chunk Folder that will generate on this script too"""    
    def __init__(self,location,directory):
        self.location = location
        self.directory = directory
    def copy_camera_accuracy(location,directory):
        path_move = os.path.join(location,directory)
        os.mkdir(path_move)

        substring = "Camera Accuracy"
        for file in os.listdir(location):
            if file.find(substring) != -1:
                shutil.move(os.path.join(location,file),os.path.join(location,directory))